@@ -1,11 +1,9 @@
 from .createPkg import *
-from cpkgtab import *
 __author__ = 'xiongtianshuo'
-__version__ = '0.0.12'
+__version__ = '0.0.15'
 __all__ = [
     'NameNotSpecificationError',
     'PathNotFoundError',
     'PathNotFoundError',
     'create'
 ]
-ctab(__version__, create)
